# 4byte CLI Commands

- [`ctc 4byte <signature>`](#ctc-4byte-signature)
- [`ctc 4byte build`](#ctc-4byte-build)
- [`ctc 4byte path`](#ctc-4byte-path)

## `ctc 4byte <signature>`

lookup function or event signature in 4bytes database

## `ctc 4byte build [functions|events]`

build local copy of 4byte database

this is useful for performing many 4byte queries

## `ctc 4byte path`

print locations where local copy of 4byte database are saved

